@@ -28,6 +28,7 @@ from cript import exceptions  # noqa 401 402
 from cript.nodes import (  # noqa 402
     User,
     Group,
+    Project,
     Reference,
     Citation,
     Collection,
@@ -36,11 +37,11 @@ from cript.nodes import (  # noqa 402
     Condition,
     Property,
     Identifier,
-    Component,
     Material,
     Inventory,
     Quantity,
     Ingredient,
+    Equipment,
     Process,
     Experiment,
 )
@@ -48,6 +49,7 @@ from cript.nodes import (  # noqa 402
 NODE_CLASSES = [
     User,
     Group,
+    Project,
     Reference,
     Citation,
     Collection,
@@ -56,11 +58,11 @@ NODE_CLASSES = [
     Condition,
     Property,
     Identifier,
-    Component,
     Material,
     Inventory,
     Quantity,
     Ingredient,
+    Equipment,
     Process,
     Experiment,
 ]
