@@ -18,7 +18,12 @@ from cript.nodes.primary.base_primary import BasePrimary
 from cript.nodes.primary.user import User
 from cript.nodes.primary.file import File
 from cript.nodes.secondary.base_secondary import BaseSecondary
-from cript.utils import get_api_url, convert_file_size, display_errors
+from cript.utils import (
+    get_api_url,
+    convert_to_api_url,
+    convert_file_size,
+    display_errors,
+)
 from cript.exceptions import (
     APIAuthError,
     APIRefreshError,
@@ -113,12 +118,15 @@ class API:
             )
 
     @beartype
-    def save(self, node: BasePrimary, max_level: int = 1):
+    def save(
+        self, node: BasePrimary, max_level: int = 1, update_existing: bool = False
+    ):
         """
         Create or update a node in the database.
 
         :param node: The node to be saved.
         :param max_level: Max depth to recursively generate nested nodes.
+        :param update_existing: Indicates whether to update an existing node with the same unique fields.
         """
         if not isinstance(node, BasePrimary):
             raise APISaveError(
@@ -152,12 +160,18 @@ class API:
 
         else:
             try:
-                # Raise error if duplicate node is found
+                # Check if a duplicate error was returned
                 response_dict = json.loads(response.content)
                 if "duplicate" in response_dict:
-                    response_dict.pop("duplicate")  # Pop flag for display purposes
-                    response_content = json.dumps(response_dict)
-                    raise DuplicateNodeError(display_errors(response_content))
+                    duplicate_url = response_dict.pop("duplicate")
+                    if update_existing == True and duplicate_url is not None:
+                        # Update existing duplicate node
+                        node.url = duplicate_url
+                        self.save(node)
+                        return
+                    else:
+                        response_content = json.dumps(response_dict)
+                        raise DuplicateNodeError(display_errors(response_content))
             except json.decoder.JSONDecodeError:
                 pass
             raise APISaveError(display_errors(response.content))
@@ -547,44 +561,44 @@ class API:
             raise APIGetError(display_errors(response.content))
 
     @beartype
-    def search(self, node_class: Type[BasePrimary], query: dict = None):
+    def search(
+        self,
+        node_class: Type[BasePrimary],
+        query: dict,
+        limit: Union[int, None] = None,
+        offset: Union[int, None] = None,
+    ):
         """
         Send a query to the API and print the results.
 
         :param node_class: The class of the node type to query for.
         :param query: A dictionary defining the query parameters (e.g., {"name": "NewMaterial"}).
-        :return: A :class:`JSONPaginator` object containing the results.
-        :rtype: cript.session.JSONPaginator
+        :param limit: The max number of items to return.
+        :param offset: The starting position of the query.
+        :return: A :class:`SearchPaginator` object containing the results.
+        :rtype: cript.session.SearchPaginator
         """
         if not issubclass(node_class, BasePrimary):
             raise APISearchError(
                 f"{node_class.node_name} is a secondary node, thus cannot be searched."
             )
 
+        # Generate URL
+        url = f"{self.api_url}/search/{node_class.slug}/?"
+        if limit:
+            url += f"limit={str(limit)}&"
+        if offset:
+            url += f"offset={str(offset)}"
+
         if isinstance(query, dict):
-            query_slug = self._generate_query_slug(query)
-            response = self.session.get(
-                f"{self.api_url}/{node_class.slug}/?{query_slug}"
-            )
-        elif query is None:
-            response = self.session.get(f"{self.api_url}/{node_class.slug}/")
+            payload = json.dumps(query)
+            response = self.session.post(url=url, data=payload)
         else:
             raise APISearchError(f"'{query}' is not a valid query.")
 
         if response.status_code != 200:
             raise APISearchError(display_errors(response.content))
-        return JSONPaginator(self.session, response.content)
-
-    @staticmethod
-    def _generate_query_slug(query):
-        """Generate the query URL slug."""
-        slug = ""
-        for key in query:
-            value = query[key]
-            if isinstance(value, str):
-                value = urllib.parse.quote(value.encode("utf8"))
-            slug += f"{key}={value}&"
-        return slug
+        return SearchPaginator(self.session, response.content, payload)
 
     @beartype
     def get(
@@ -606,6 +620,7 @@ class API:
         """
         # Get node with a URL
         if isinstance(obj, str):
+            obj = convert_to_api_url(obj)
             if self.api_url not in obj:
                 raise APIGetError("Please enter a valid node URL.")
             response = self.session.get(obj)
@@ -745,7 +760,7 @@ class API:
         # Create node
         node = node_class(**obj_json)
 
-        # Replace comon attributes
+        # Replace common attributes
         node.url = url
         node.uid = uid
         node.created_at = created_at
@@ -768,11 +783,12 @@ class API:
         return None
 
 
-class JSONPaginator:
-    """Paginate JSON response content sent from the API."""
+class SearchPaginator:
+    """Paginate search JSON response content."""
 
-    def __init__(self, session, content):
+    def __init__(self, session, content, payload):
         self._session = session
+        self.payload = payload
         self.current = content
         self.count = self.current["count"]
 
@@ -795,39 +811,17 @@ class JSONPaginator:
         """Flip to the next page."""
         next_url = self.current["next"]
         if next_url:
-            response = self._session.get(next_url)
+            response = self._session.post(url=next_url, data=self.payload)
             self.current = response.content
         else:
-            raise AttributeError("You're currently on the final page.")
+            raise AttributeError("You've reached the end of the query.")
 
     @property
     def previous(self):
         """Flip to the previous page."""
         previous_url = self.current["previous"]
         if previous_url:
-            response = self._session.get(previous_url)
+            response = self._session.post(url=previous_url, data=self.payload)
             self.current = response.content
         else:
-            raise AttributeError("You're currently on the first page.")
-
-    def to_page(self, page_number: int):
-        """
-        Navigate to a specific page in the results.
-
-        :param page_number: The page number to turn to.
-        """
-        if self.current["next"]:
-            url = self.current["next"]
-        elif self.current["previous"]:
-            url = self.current["previous"]
-        else:
-            raise ValueError(f"{page_number} is not a valid page number.")
-
-        url = url.split("?page=")[0]
-        url += f"?page={str(page_number)}"
-
-        response = self._session.get(url)
-        if response.status_code == 200:
-            self.current = response.content
-        else:
-            raise ValueError(f"{page_number} is not a valid page number.")
+            raise AttributeError("You've reached the beginning of the query.")
