@@ -3,6 +3,7 @@ from cript.nodes.primary.user import User
 from cript.nodes.primary.group import Group
 from cript.nodes.primary.reference import Reference
 from cript.nodes.secondary.citation import Citation
+from cript.nodes.primary.project import Project
 from cript.nodes.primary.collection import Collection
 from cript.nodes.primary.experiment import Experiment
 from cript.nodes.primary.data import Data
@@ -11,8 +12,8 @@ from cript.nodes.secondary.condition import Condition
 from cript.nodes.secondary.property import Property
 from cript.nodes.secondary.identifier import Identifier
 from cript.nodes.secondary.quantity import Quantity
-from cript.nodes.secondary.component import Component
 from cript.nodes.primary.material import Material
 from cript.nodes.primary.inventory import Inventory
 from cript.nodes.secondary.ingredient import Ingredient
+from cript.nodes.secondary.equipment import Equipment
 from cript.nodes.primary.process import Process
