@@ -5,8 +5,9 @@ from beartype import beartype
 
 from cript.nodes.primary.base_primary import BasePrimary
 from cript.nodes.primary.group import Group
+from cript.nodes.primary.project import Project
 from cript.nodes.secondary.citation import Citation
-from cript.validators import validate_required
+from cript.utils import auto_assign_group
 
 
 logger = getLogger(__name__)
@@ -20,28 +21,27 @@ class Collection(BasePrimary):
 
     node_name = "Collection"
     slug = "collection"
-    required = ["group", "name"]
-    unique_together = ["name", "created_by"]
 
     @beartype
     def __init__(
         self,
-        group: Union[Group, str] = None,
-        name: str = None,
+        project: Union[Project, str],
+        name: str,
         experiments=None,
         inventories=None,
         notes: Union[str, None] = None,
         citations: list[Union[Citation, dict]] = None,
         public: bool = False,
+        group: Union[Group, str] = None,
     ):
         super().__init__(public=public)
-        self.group = group
+        self.project = project
         self.name = name
         self.experiments = experiments if experiments else []
         self.inventories = inventories if inventories else []
         self.citations = citations if citations else []
         self.notes = notes
-        validate_required(self)
+        self.group = auto_assign_group(group, project)
 
     @beartype
     def add_citation(self, citation: Union[Citation, dict]):
