@@ -4,8 +4,12 @@ from logging import getLogger
 from beartype import beartype
 
 from cript.nodes.primary.base_primary import BasePrimary
-from cript.nodes import Group, Identifier, Component, Property
-from cript.validators import validate_required, validate_key
+from cript.nodes.primary.group import Group
+from cript.nodes.primary.project import Project
+from cript.nodes.secondary.identifier import Identifier
+from cript.nodes.secondary.property import Property
+from cript.validators import validate_key
+from cript.utils import auto_assign_group
 
 
 logger = getLogger(__name__)
@@ -17,24 +21,23 @@ class Material(BasePrimary):
     node_name = "Material"
     slug = "material"
     list_name = "materials"
-    required = ["group", "name"]
-    unique_together = ["name", "created_by"]
 
     @beartype
     def __init__(
         self,
-        group: Union[Group, str] = None,
-        name: str = None,
+        project: Union[Project, str],
+        name: str,
         identifiers: list[Union[Identifier, dict]] = None,
-        components: list[Union[Component, dict]] = None,
+        components: list[Union[BasePrimary, str]] = None,
         keywords: Union[list[str], None] = None,
-        process: Union[BasePrimary, str, None] = None,  # Needs more specific type check
+        process: Union[BasePrimary, str, None] = None,
         properties: list[Union[Property, dict]] = None,
         notes: Union[str, None] = None,
         public: bool = False,
+        group: Union[Group, str] = None,
     ):
         super().__init__(public=public)
-        self.group = group
+        self.project = project
         self.name = name
         self.identifiers = identifiers if identifiers else []
         self.components = components if components else []
@@ -42,7 +45,7 @@ class Material(BasePrimary):
         self.process = process
         self.properties = properties if properties else []
         self.notes = notes
-        validate_required(self)
+        self.group = auto_assign_group(group, project)
 
     @property
     def keywords(self):
@@ -64,11 +67,11 @@ class Material(BasePrimary):
         self._remove_node(identifier, "identifiers")
 
     @beartype
-    def add_component(self, component: Union[Component, dict]):
+    def add_component(self, component: Union[BasePrimary, dict]):
         self._add_node(component, "components")
 
     @beartype
-    def remove_component(self, component: Union[Component, int]):
+    def remove_component(self, component: Union[BasePrimary, int]):
         self._remove_node(component, "components")
 
     @beartype
