@@ -6,7 +6,7 @@ from beartype import beartype
 from cript.nodes.primary.material import Material
 from cript.nodes.secondary.quantity import Quantity
 from cript.nodes.secondary.base_secondary import BaseSecondary
-from cript.validators import validate_required, validate_key
+from cript.validators import validate_key
 
 
 logger = getLogger(__name__)
@@ -20,7 +20,6 @@ class Ingredient(BaseSecondary):
 
     node_name = "Ingredient"
     list_name = "ingredients"
-    required = ["material"]
 
     @beartype
     def __init__(
@@ -33,7 +32,6 @@ class Ingredient(BaseSecondary):
         self.material = material
         self.keyword = keyword
         self.quantities = quantities if quantities else []
-        validate_required(self)
 
     @property
     def keyword(self):
