@@ -3,17 +3,12 @@ from logging import getLogger
 
 from beartype import beartype
 
-
+from cript.nodes.primary.base_primary import BasePrimary
 from cript.nodes.primary.data import Data
 from cript.nodes.secondary.base_secondary import BaseSecondary
 from cript.nodes.secondary.condition import Condition
 from cript.nodes.secondary.citation import Citation
-from cript.validators import (
-    validate_required,
-    validate_key,
-    validate_value,
-    validate_unit,
-)
+from cript.validators import validate_key, validate_value, validate_unit
 
 
 logger = getLogger(__name__)
@@ -27,25 +22,27 @@ class Property(BaseSecondary):
 
     node_name = "Property"
     list_name = "properties"
-    required = ["key"]
 
     @beartype
     def __init__(
         self,
-        key: str = None,
+        key: str,
         value: Union[str, int, float, list, None] = None,
         unit: Union[str, None] = None,
         type: Union[str, None] = None,
         method: Union[str, None] = None,
         method_description: Union[str, None] = None,
+        sample_preparation: Union[BasePrimary, str, None] = None,
         uncertainty: Union[float, int, None] = None,
         uncertainty_type: Union[str, None] = None,
-        component_id: Union[int, None] = None,
+        components: list[Union[BasePrimary, str]] = None,
+        components_relative: list[Union[BasePrimary, str]] = None,
         structure: Union[str, None] = None,
         set_id: Union[int, None] = None,
         conditions: list[Union[Condition, dict]] = None,
-        data: list[Union[Data, str]] = None,
+        data: Union[Data, str, None] = None,
         citations: list[Union[Citation, dict]] = None,
+        notes: Union[str, None] = None,
     ):
         super().__init__()
         self.key = key
@@ -54,15 +51,17 @@ class Property(BaseSecondary):
         self.type = type
         self.method = method
         self.method_description = method_description
+        self.sample_preparation = sample_preparation
         self.uncertainty = uncertainty
         self.uncertainty_type = uncertainty_type
-        self.component_id = component_id
+        self.components = components if components else []
+        self.components_relative = components_relative if components_relative else []
         self.structure = structure
         self.set_id = set_id
         self.conditions = conditions if conditions else []
-        self.data = data if data else []
+        self.data = data
         self.citations = citations if citations else []
-        validate_required(self)
+        self.notes = notes
 
     @property
     def key(self):
@@ -113,12 +112,20 @@ class Property(BaseSecondary):
         self._uncertainty_type = validate_key("uncertainty-type", value)
 
     @beartype
-    def add_data(self, data: Union[Data, dict]):
-        self._add_node(data, "data")
+    def add_components(self, component: Union[BasePrimary, dict]):
+        self._add_node(component, "components")
 
     @beartype
-    def remove_data(self, data: Union[Data, int]):
-        self._remove_node(data, "data")
+    def remove_components(self, component: Union[BasePrimary, int]):
+        self._remove_node(component, "components")
+
+    @beartype
+    def add_components_relative(self, component: Union[BasePrimary, dict]):
+        self._add_node(component, "components_relative")
+
+    @beartype
+    def remove_components_relative(self, component: Union[BasePrimary, int]):
+        self._remove_node(component, "components_relative")
 
     @beartype
     def add_condition(self, condition: Union[Condition, dict]):
